//
// EPSSoundPlayer.m
// Created by Peter Stuart of Electric Peal Software
//
//

#import "EPSSoundPlayer.h"
#import <AudioToolbox/AudioToolbox.h>

@implementation EPSSoundPlayer

static void MyCompletionCallback (
								  SystemSoundID  mySSID,
								  void * myURLRef
								  ) {
	AudioServicesDisposeSystemSoundID (mySSID);
	CFRelease (myURLRef);
	CFRunLoopStop (CFRunLoopGetCurrent());
}

- (void)playSoundWithName:(NSString *)fileName extension:(NSString *)extension {
	if (!fileName) return;
	
	NSString *path = [[NSBundle mainBundle] pathForResource:fileName ofType:extension];
	
	if (!path) return;
	
	// Set up the pieces needed to play a sound.
    SystemSoundID    mySSID;
    CFURLRef        myURLRef;
	
	CFStringRef fileNameRef = (CFStringRef)path;
    myURLRef = CFURLCreateWithFileSystemPath (
											  kCFAllocatorDefault,
											  fileNameRef,
											  kCFURLPOSIXPathStyle,
											  FALSE
											  );
	
    // create a system sound ID to represent the sound file
    //OSStatus error = 
	AudioServicesCreateSystemSoundID (myURLRef, &mySSID);
	
    // Register the sound completion callback.
    // Again, useful when you need to free memory after playing.
    AudioServicesAddSystemSoundCompletion (
										   mySSID,
										   NULL,
										   NULL,
										   MyCompletionCallback,
										   (void *) myURLRef
										   );
	
    // Play the sound file.
    AudioServicesPlaySystemSound (mySSID);
}

- (void)playRightAnswerSound {
	[self playSoundWithName:@"RightAnswer" extension:@"wav"];
}

- (void)playWrongAnswerSound {
	[self playSoundWithName:@"WrongAnswer" extension:@"wav"];
}

@end
