//
//  Hangmanipad2ViewController.m
//  Hangmanipad2
//
//  Created by Laurence Ehrhardt on 4/13/11.
//  Copyright 2011 Ballast Lane Applications. All rights reserved.
//

#import "Hangmanipad2ViewController.h"
#import "EPSSoundPlayer.h"
#import "SettingsViewController.h"
#import "ModalViewController.h"

@implementation Hangmanipad2ViewController

@synthesize soundPlayer;
@synthesize letterButton;
@synthesize wordLabel;
@synthesize displayWord;
@synthesize newGameButton;
@synthesize settingsButton;
@synthesize hangmanImage;
@synthesize evilImage;
@synthesize gameWord;
@synthesize wrongAnswerCount;
@synthesize popover;


- (void) gameLevelSelected:(NSString *) gameLevel 
{
    NSLog(@"Game Level %@", gameLevel);
    
    NSString *fileName = [[NSString stringWithFormat:@"%@", gameLevel] stringByAppendingString:@".png"];        
    
    evilImage.image = [UIImage imageNamed: fileName];
    
    
    

}

- (void)viewDidLoad {
    
    [super viewDidLoad];
    
    //Words need to be in all Caps
    gameWord = @"BULLDOGS";
    
    displayWord = [[[NSMutableString alloc] initWithFormat:@"_ _ _ _ _ _ _ _"] retain];
    
    wordLabel.text = displayWord;
    
    self.wrongAnswerCount = 0;

}

- (EPSSoundPlayer *)soundPlayer {
	if (soundPlayer == nil) {
		self.soundPlayer = [[[EPSSoundPlayer alloc] init] autorelease];
	}
	
	return soundPlayer;
}


- (IBAction) newGame:(id) sender {
    NSLog(@"New Game Pressed");
    [self newGame];
}

- (IBAction) showSettings:(id) sender {
    NSLog(@"Settings Pressed");
    
    if ([popover isPopoverVisible]) {
		[popover dismissPopoverAnimated:YES];
	}
	else {
        
        SettingsViewController *s = [[SettingsViewController alloc] init];
        s.delegate =self;
        
        popover = [[UIPopoverController alloc]
                   initWithContentViewController:s];
        [s release];
		
        [popover presentPopoverFromRect:[sender frame] inView:self.view permittedArrowDirections:UIPopoverArrowDirectionAny animated:YES];
	}
    
}

- (IBAction) submitLetter:(id) sender {
    
    UIButton *b = (UIButton *)sender;
    
    NSString *letter = b.titleLabel.text; 
    
    NSLog(@"Letter Pressed %@", letter);

    if ([gameWord rangeOfString:b.titleLabel.text].location == NSNotFound) {
        
        [self.soundPlayer playWrongAnswerSound];
        
        [b setBackgroundImage:[UIImage imageNamed:@"buttonRed.png"] forState:UIControlStateNormal];
        
        b.enabled = NO;
        
        self.wrongAnswerCount = self.wrongAnswerCount +1;
            
        NSString *fileName = [[NSString stringWithFormat:@"%d", wrongAnswerCount] stringByAppendingString:@".png"];        

        hangmanImage.image = [UIImage imageNamed: fileName];
    
    } else {
        
        [self.soundPlayer playRightAnswerSound];
        [b setBackgroundImage:[UIImage imageNamed:@"buttonGreen.png"] forState:UIControlStateNormal];
        b.enabled = NO;
        
        for (int y=0;y<[gameWord length];y++){
            
            NSRange range = {y,1};
            
            NSLog(@"Letter %@", letter);
            
            NSString *testLetter = [gameWord substringWithRange:range];
            
            if ([testLetter isEqualToString: letter]){
            
                [displayWord replaceCharactersInRange: NSMakeRange((y*2), 1) withString:letter];
            
            }
            
        }
        
        wordLabel.text = displayWord;

    }
    
    if ([displayWord isEqualToString:@"B U L L D O G S"] && self.wrongAnswerCount < 7) {
        
        ModalViewController *m = [[ModalViewController alloc] initWithNibName:@"ModalViewController" bundle:nil];
        
        m.modalTransitionStyle = UIModalTransitionStyleCoverVertical;	
        m.modalPresentationStyle = UIModalPresentationFormSheet;
        
        [self presentModalViewController:m animated:YES];
        
        [m release];

    }
    
    if (![displayWord isEqualToString:@"B U L L D O G S"] && self.wrongAnswerCount >= 7) {        
        
        [NSThread sleepForTimeInterval:2];

        [self newGame];
        
    }

}

- (void)newGame {
    
    displayWord = [[[NSMutableString alloc] initWithFormat:@"_ _ _ _ _ _ _ _"] retain];
    
    wordLabel.text = displayWord;
    
    self.wrongAnswerCount = 0;
    
    NSString *fileName = [[NSString stringWithFormat:@"0"] stringByAppendingString:@".png"];        
    
    hangmanImage.image = [UIImage imageNamed: fileName];
    
    for(UIButton *b in self.view.subviews) {
        
        
        if ([b isKindOfClass:[UIButton class]]) {
            
             NSLog(@"Change Button State");
             NSLog (@"Text %@", b.titleLabel.text);
            
            if(b.titleLabel.text) {
                
                NSLog (@"Text %@", b.titleLabel.text);
               
                [b setBackgroundImage:[UIImage imageNamed:@"buttonGray.png"] forState:UIControlStateNormal];
                b.enabled = YES;
                }
            }
        }
    
}

- (void)dealloc
{
    [popover release];
    [wordLabel release];
    [displayWord release];
    [soundPlayer release];
    [super dealloc];
}

- (void)didReceiveMemoryWarning
{
    // Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
    
    // Release any cached data, images, etc that aren't in use.
}

#pragma mark - View lifecycle

/*
// Implement viewDidLoad to do additional setup after loading the view, typically from a nib.
- (void)viewDidLoad
{
    [super viewDidLoad];
}
*/

- (void)viewDidUnload
{
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    // e.g. self.myOutlet = nil;
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    // Return YES for supported orientations

    return NO;
}

@end
